@@ -1,5 +1,6 @@
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 01.09.2022: Compacted gui. Fixed narrow dropdowns. Removed destroy workaround.
 # 03.03.2020: Fixed reference to function name.
 # 23.02.2020: Added language support.
 # 03.03.2019: Compacted and tweaked widgets under tcltk.
@@ -163,28 +164,13 @@ addDye_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pare
       focus(parent)
     }
 
-    # Check which toolkit we are using.
-    if (gtoolkit() == "tcltk") {
-      if (as.numeric(gsub("[^0-9]", "", packageVersion("gWidgets2tcltk"))) <= 106) {
-        # Version <= 1.0.6 have the wrong implementation:
-        # See: https://stackoverflow.com/questions/54285836/how-to-retrieve-checkbox-state-in-gwidgets2tcltk-works-in-gwidgets2rgtk2
-        message("tcltk version <= 1.0.6, returned TRUE!")
-        return(TRUE) # Destroys window under tcltk, but not RGtk2.
-      } else {
-        # Version > 1.0.6 will be fixed:
-        # https://github.com/jverzani/gWidgets2tcltk/commit/9388900afc57454b6521b00a187ca4a16829df53
-        message("tcltk version >1.0.6, returned FALSE!")
-        return(FALSE) # Destroys window under tcltk, but not RGtk2.
-      }
-    } else {
-      message("RGtk2, returned FALSE!")
-      return(FALSE) # Destroys window under RGtk2, but not with tcltk.
-    }
+    # Destroy window.
+    return(FALSE)
   })
 
   gv <- ggroup(
     horizontal = FALSE,
-    spacing = 5,
+    spacing = 1,
     use.scrollwindow = FALSE,
     container = w,
     expand = TRUE
@@ -210,15 +196,20 @@ addDye_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pare
   f0 <- gframe(
     text = strFrmDataset,
     horizontal = FALSE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
-  f0g0 <- glayout(container = f0, spacing = 1)
+  f0g0 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
 
-  f0g0[1, 1] <- glabel(text = strLblDataset, container = f0g0)
+  glabel(text = strLblDataset, container = f0g0)
 
-  f0g0[1, 2] <- dataset_drp <- gcombobox(
+  dataset_samples_lbl <- glabel(
+    text = paste(" 0", strLblSamples),
+    container = f0g0
+  )
+
+  dataset_drp <- gcombobox(
     items = c(
       strDrpDefault,
       listObjects(
@@ -229,12 +220,9 @@ addDye_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pare
     selected = 1,
     editable = FALSE,
     container = f0g0,
-    ellipsize = "none"
-  )
-
-  f0g0[1, 3] <- dataset_samples_lbl <- glabel(
-    text = paste(" 0", strLblSamples),
-    container = f0g0
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
   addHandlerChanged(dataset_drp, handler = function(h, ...) {
@@ -269,21 +257,23 @@ addDye_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pare
 
   # KIT -----------------------------------------------------------------------
 
-  f0g0[2, 1] <- glabel(text = strLblKit, container = f0g0)
+  f0g1 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
+
+  glabel(text = strLblKit, container = f0g1)
 
   kit_drp <- gcombobox(
     items = getKit(),
     selected = 1,
     editable = FALSE,
-    container = f0g0,
-    ellipsize = "none"
+    container = f0g1,
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
-  f0g0[2, 2] <- kit_drp
-
   # FRAME 1 ###################################################################
 
-  f1 <- gframe(text = strFrmOptions, horizontal = FALSE, spacing = 2, container = gv)
+  f1 <- gframe(text = strFrmOptions, horizontal = FALSE, spacing = 1, container = gv)
 
   f1_ignore_chk <- gcheckbox(
     text = strChkIgnore,
