@@ -3,6 +3,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 01.09.2022: Compacted gui. Fixed narrow dropdowns. Removed destroy workaround.
 # 03.03.2020: Fixed reference to function name.
 # 29.02.2020: Added language support.
 # 17.02.2019: Fixed Error in if (svalue(savegui_chk)) { : argument is of length zero (tcltk)
@@ -265,28 +266,13 @@ calculateAT_gui <- function(env = parent.frame(), savegui = NULL,
       focus(parent)
     }
 
-    # Check which toolkit we are using.
-    if (gtoolkit() == "tcltk") {
-      if (as.numeric(gsub("[^0-9]", "", packageVersion("gWidgets2tcltk"))) <= 106) {
-        # Version <= 1.0.6 have the wrong implementation:
-        # See: https://stackoverflow.com/questions/54285836/how-to-retrieve-checkbox-state-in-gwidgets2tcltk-works-in-gwidgets2rgtk2
-        message("tcltk version <= 1.0.6, returned TRUE!")
-        return(TRUE) # Destroys window under tcltk, but not RGtk2.
-      } else {
-        # Version > 1.0.6 will be fixed:
-        # https://github.com/jverzani/gWidgets2tcltk/commit/9388900afc57454b6521b00a187ca4a16829df53
-        message("tcltk version >1.0.6, returned FALSE!")
-        return(FALSE) # Destroys window under tcltk, but not RGtk2.
-      }
-    } else {
-      message("RGtk2, returned FALSE!")
-      return(FALSE) # Destroys window under RGtk2, but not with tcltk.
-    }
+    # Destroy window.
+    return(FALSE)
   })
 
   gv <- ggroup(
     horizontal = FALSE,
-    spacing = 5,
+    spacing = 1,
     use.scrollwindow = FALSE,
     container = w,
     expand = TRUE
@@ -310,30 +296,36 @@ calculateAT_gui <- function(env = parent.frame(), savegui = NULL,
   # FRAME 0 ###################################################################
 
   f0 <- gframe(
-    text = "Datasets",
-    horizontal = TRUE,
-    spacing = 5,
-    container = gv
+    text = strFrmDataset,
+    horizontal = FALSE,
+    spacing = 1,
+    container = gv,
+    expand = FALSE,
+    fill = "x"
   )
 
-  g0 <- glayout(container = f0, spacing = 1)
-
   # Dataset -------------------------------------------------------------------
 
-  g0[1, 1] <- glabel(text = strLblDataset, container = g0)
+  g0 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
 
+  glabel(text = strLblDataset, container = g0)
+
+  g0_data_samples_lbl <- glabel(
+    text = paste(" 0", strLblSamples),
+    container = g0
+  )
+
+  # Create default dropdown.
   dfs <- c(strDrpDefault, listObjects(env = env, obj.class = "data.frame"))
 
-  g0[1, 2] <- g0_data_drp <- gcombobox(
+  g0_data_drp <- gcombobox(
     items = dfs,
     selected = 1,
     editable = FALSE,
     container = g0,
-    ellipsize = "none"
-  )
-  g0[1, 3] <- g0_data_samples_lbl <- glabel(
-    text = paste(" 0", strLblSamples),
-    container = g0
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
   addHandlerChanged(g0_data_drp, handler = function(h, ...) {
@@ -370,7 +362,7 @@ calculateAT_gui <- function(env = parent.frame(), savegui = NULL,
       # Detect kit.
       kitIndex <- detectKit(data = .gData, index = TRUE, debug = debug)
       # Select in dropdown.
-      svalue(g0_kit_drp, index = TRUE) <- kitIndex
+      svalue(g2_kit_drp, index = TRUE) <- kitIndex
     } else {
 
       # Reset components.
@@ -387,24 +379,25 @@ calculateAT_gui <- function(env = parent.frame(), savegui = NULL,
 
   # Reference -----------------------------------------------------------------
 
-  g0[2, 1] <- glabel(text = strLblDatasetRef, container = g0)
+  g1 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
+  glabel(text = strLblDatasetRef, container = g1)
+
+  g1_ref_samples_lbl <- glabel(
+    text = paste(" 0", strLblRef),
+    container = g1
+  )
 
   # NB! dfs defined in previous section.
-  g0[2, 2] <- g0_ref_drp <- gcombobox(
+  g1_ref_drp <- gcombobox(
     items = dfs,
     selected = 1,
     editable = FALSE,
-    container = g0,
-    ellipsize = "none"
+    container = g1,
+    ellipsize = "none", expand = TRUE, fill = "x"
   )
 
-  g0[2, 3] <- g0_ref_samples_lbl <- glabel(
-    text = paste(" 0", strLblRef),
-    container = g0
-  )
-
-  addHandlerChanged(g0_ref_drp, handler = function(h, ...) {
-    val_obj <- svalue(g0_ref_drp)
+  addHandlerChanged(g1_ref_drp, handler = function(h, ...) {
+    val_obj <- svalue(g1_ref_drp)
 
     # Check if suitable.
     requiredCol <- c("Sample.Name", "Marker", "Allele")
@@ -418,7 +411,7 @@ calculateAT_gui <- function(env = parent.frame(), savegui = NULL,
       # Load or change components.
 
       .gRef <<- get(val_obj, envir = env)
-      svalue(g0_ref_samples_lbl) <- paste(
+      svalue(g1_ref_samples_lbl) <- paste(
         length(unique(.gRef$Sample.Name)),
         strLblSamples
       )
@@ -426,16 +419,30 @@ calculateAT_gui <- function(env = parent.frame(), savegui = NULL,
 
       # Reset components.
       .gRef <<- NULL
-      svalue(g0_ref_drp, index = TRUE) <- 1
-      svalue(g0_ref_samples_lbl) <- paste(" 0", strLblRef)
+      svalue(g1_ref_drp, index = TRUE) <- 1
+      svalue(g1_ref_samples_lbl) <- paste(" 0", strLblRef)
     }
   })
 
-  # CHECK ---------------------------------------------------------------------
+  # Kit -----------------------------------------------------------------------
 
-  g0[3, 2] <- g0_check_btn <- gbutton(text = strBtnCheck, container = g0)
+  g2 <- ggroup(container = f0, expand = TRUE, fill = "x")
+  glabel(text = strLblKit, container = g2)
 
-  addHandlerChanged(g0_check_btn, handler = function(h, ...) {
+  g2_kit_drp <- gcombobox(
+    items = getKit(),
+    selected = 1,
+    editable = FALSE,
+    container = g2,
+    ellipsize = "none", expand = TRUE, fill = "x"
+  )
+  tooltip(g2_kit_drp) <- strTipKit
+
+  # CHECK #####################################################################
+
+  check_btn <- gbutton(text = strBtnCheck, expande = TRUE, container = gv)
+
+  addHandlerChanged(check_btn, handler = function(h, ...) {
 
     # Get values.
     val_data <- .gData
@@ -474,26 +481,12 @@ calculateAT_gui <- function(env = parent.frame(), savegui = NULL,
     }
   })
 
-  # Kit -----------------------------------------------------------------------
-
-  g0[4, 1] <- glabel(text = strLblKit, container = g0)
-
-  # NB! dfs defined in previous section.
-  g0[4, 2] <- g0_kit_drp <- gcombobox(
-    items = getKit(),
-    selected = 1,
-    editable = FALSE,
-    container = g0,
-    ellipsize = "none"
-  )
-  tooltip(g0_kit_drp) <- strTipKit
-
   # FRAME 1 ###################################################################
 
   f1 <- gframe(
     text = strFrmOptions,
     horizontal = FALSE,
-    spacing = 10,
+    spacing = 1,
     container = gv
   )
 
@@ -579,15 +572,17 @@ calculateAT_gui <- function(env = parent.frame(), savegui = NULL,
   f3 <- gframe(
     text = strFrmPrepare,
     horizontal = TRUE,
-    spacing = 5,
-    container = gv
+    spacing = 1,
+    container = gv,
+    expand = TRUE,
+    fill = "x"
   )
 
   mask_btn <- gbutton(text = strBtnMask, container = f3)
 
   f3_sample_drp <- gcombobox(
     items = strDrpDefault2, selected = 1,
-    editable = FALSE, container = f3, ellipsize = "none"
+    editable = FALSE, container = f3, ellipsize = "none", expand = TRUE, fill = "x"
   )
 
   save_btn <- gbutton(text = strBtnSave, container = f3)
@@ -676,7 +671,7 @@ calculateAT_gui <- function(env = parent.frame(), savegui = NULL,
       val_mask_ils <- svalue(f1_mask_ils_chk)
       val_range <- svalue(f1_mask_spb)
       val_range_ils <- svalue(f1_mask_ils_spb)
-      val_kit <- svalue(g0_kit_drp)
+      val_kit <- svalue(g2_kit_drp)
 
       if (val_sample %in% unique(.gDataPrep$Sample.File.Name)) {
 
@@ -871,7 +866,7 @@ calculateAT_gui <- function(env = parent.frame(), savegui = NULL,
   f4 <- gframe(
     text = strFrmSave,
     horizontal = FALSE,
-    spacing = 5,
+    spacing = 1,
     container = gv
   )
 
@@ -902,7 +897,7 @@ calculateAT_gui <- function(env = parent.frame(), savegui = NULL,
     }
     val_ref <- .gRef
     val_name_data <- svalue(g0_data_drp)
-    val_name_ref <- svalue(g0_ref_drp)
+    val_name_ref <- svalue(g1_ref_drp)
     val_ignore <- svalue(f1_ignore_chk)
     val_word <- svalue(f1_word_chk)
     val_mask_h <- svalue(f1_mask_h_chk)
