@@ -1,5 +1,6 @@
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 05.09.2022: Compacted gui. Fixed narrow dropdowns. Removed destroy workaround.
 # 03.03.2020: Added language support.
 # 20.03.2019: Added new option to calculate balance (Issue:#14).
 # 15.02.2019: Expand text fields in tcltk by setting fill = TRUE.
@@ -246,28 +247,14 @@ calculateLb_gui <- function(env = parent.frame(), savegui = NULL,
     if (!is.null(parent)) {
       focus(parent)
     }
-    # Check which toolkit we are using.
-    if (gtoolkit() == "tcltk") {
-      if (as.numeric(gsub("[^0-9]", "", packageVersion("gWidgets2tcltk"))) <= 106) {
-        # Version <= 1.0.6 have the wrong implementation:
-        # See: https://stackoverflow.com/questions/54285836/how-to-retrieve-checkbox-state-in-gwidgets2tcltk-works-in-gwidgets2rgtk2
-        message("tcltk version <= 1.0.6, returned TRUE!")
-        return(TRUE) # Destroys window under tcltk, but not RGtk2.
-      } else {
-        # Version > 1.0.6 will be fixed:
-        # https://github.com/jverzani/gWidgets2tcltk/commit/9388900afc57454b6521b00a187ca4a16829df53
-        message("tcltk version >1.0.6, returned FALSE!")
-        return(FALSE) # Destroys window under tcltk, but not RGtk2.
-      }
-    } else {
-      message("RGtk2, returned FALSE!")
-      return(FALSE) # Destroys window under RGtk2, but not with tcltk.
-    }
+
+    # Destroy window.
+    return(FALSE)
   })
 
   gv <- ggroup(
     horizontal = FALSE,
-    spacing = 8,
+    spacing = 1,
     use.scrollwindow = FALSE,
     container = w,
     expand = TRUE
@@ -292,33 +279,36 @@ calculateLb_gui <- function(env = parent.frame(), savegui = NULL,
 
   f0 <- gframe(
     text = strFrmDataset,
-    horizontal = TRUE,
-    spacing = 5,
+    horizontal = FALSE,
+    spacing = 1,
     container = gv
   )
 
-  g0 <- glayout(container = f0, spacing = 1)
-
   # Dataset -------------------------------------------------------------------
 
-  g0[1, 1] <- glabel(text = strLblDataset, container = g0)
+  g0 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
 
-  dfs <- c(strDrpDataset, listObjects(env = env, obj.class = "data.frame"))
+  glabel(text = strLblDataset, container = g0)
 
-  g0[1, 2] <- g0_data_drp <- gcombobox(
-    items = dfs,
-    selected = 1,
-    editable = FALSE,
-    container = g0,
-    ellipsize = "none"
-  )
-  g0[1, 3] <- g0_data_samples_lbl <- glabel(
+  data_samples_lbl <- glabel(
     text = paste(" 0", strLblSamples),
     container = g0
   )
 
-  addHandlerChanged(g0_data_drp, handler = function(h, ...) {
-    val_obj <- svalue(g0_data_drp)
+  dfs <- c(strDrpDataset, listObjects(env = env, obj.class = "data.frame"))
+
+  data_drp <- gcombobox(
+    items = dfs,
+    selected = 1,
+    editable = FALSE,
+    container = g0,
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
+  )
+
+  addHandlerChanged(data_drp, handler = function(h, ...) {
+    val_obj <- svalue(data_drp)
 
     # Check if suitable.
     requiredCol <- c("Sample.Name", "Marker", "Height")
@@ -334,7 +324,7 @@ calculateLb_gui <- function(env = parent.frame(), savegui = NULL,
       # get dataset.
       .gData <<- get(val_obj, envir = env)
       .gDataName <<- val_obj
-      svalue(g0_data_samples_lbl) <- paste(
+      svalue(data_samples_lbl) <- paste(
         length(unique(.gData$Sample.Name)),
         strLblSamples
       )
@@ -351,33 +341,37 @@ calculateLb_gui <- function(env = parent.frame(), savegui = NULL,
       # Reset components.
       .gData <<- NULL
       .gDataName <<- NULL
-      svalue(g0_data_drp, index = TRUE) <- 1
-      svalue(g0_data_samples_lbl) <- paste(" 0", strLblSamples)
+      svalue(data_drp, index = TRUE) <- 1
+      svalue(data_samples_lbl) <- paste(" 0", strLblSamples)
       svalue(save_edt) <- ""
     }
   })
 
   # Reference -----------------------------------------------------------------
 
-  g0[2, 1] <- glabel(text = strLblRefDataset, container = g0)
+  g1 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
+
+  glabel(text = strLblRefDataset, container = g1)
+
+  ref_samples_lbl <- glabel(
+    text = paste(" 0", strLblRef),
+    container = g1
+  )
 
   # NB! dfs defined in previous section.
-  g0[2, 2] <- g0_ref_drp <- gcombobox(
+  ref_drp <- gcombobox(
     items = dfs,
     selected = 1,
     editable = FALSE,
-    container = g0,
-    ellipsize = "none"
+    container = g1,
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
-  tooltip(g0_ref_drp) <- strTipRef
+  tooltip(ref_drp) <- strTipRef
 
-  g0[2, 3] <- g0_ref_samples_lbl <- glabel(
-    text = paste(" 0", strLblRef),
-    container = g0
-  )
-
-  addHandlerChanged(g0_ref_drp, handler = function(h, ...) {
-    val_obj <- svalue(g0_ref_drp)
+  addHandlerChanged(ref_drp, handler = function(h, ...) {
+    val_obj <- svalue(ref_drp)
 
     # Check if suitable.
     requiredCol <- c("Sample.Name", "Marker", "Allele")
@@ -392,7 +386,7 @@ calculateLb_gui <- function(env = parent.frame(), savegui = NULL,
 
       .gRef <<- get(val_obj, envir = env)
       .gRefName <<- val_obj
-      svalue(g0_ref_samples_lbl) <- paste(
+      svalue(ref_samples_lbl) <- paste(
         length(unique(.gRef$Sample.Name)),
         strLblRef
       )
@@ -403,19 +397,33 @@ calculateLb_gui <- function(env = parent.frame(), savegui = NULL,
       # Reset components.
       .gRef <<- NULL
       .gRefName <<- NULL
-      svalue(g0_ref_drp, index = TRUE) <- 1
-      svalue(g0_ref_samples_lbl) <- paste(" 0", strLblRef)
+      svalue(ref_drp, index = TRUE) <- 1
+      svalue(ref_samples_lbl) <- paste(" 0", strLblRef)
 
       # Disable checkbox to calculate H.
       enabled(f1_h_chk) <- FALSE
     }
   })
 
-  # CHECK ---------------------------------------------------------------------
+  # Kit -----------------------------------------------------------------------
 
-  g0[3, 2] <- g0_check_btn <- gbutton(text = strBtnCheck, container = g0)
+  g2 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
 
-  addHandlerChanged(g0_check_btn, handler = function(h, ...) {
+  glabel(text = strLblKit, container = g2)
+
+  kit_drp <- gcombobox(
+    items = getKit(), selected = 1,
+    editable = FALSE, container = g2,
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
+  )
+
+  # CHECK #####################################################################
+
+  check_btn <- gbutton(text = strBtnCheck, container = gv)
+
+  addHandlerChanged(check_btn, handler = function(h, ...) {
 
     # Get values.
     val_data <- .gData
@@ -455,23 +463,13 @@ calculateLb_gui <- function(env = parent.frame(), savegui = NULL,
     }
   })
 
-  # Kit -----------------------------------------------------------------------
-
-  g0[4, 1] <- glabel(text = strLblKit, container = g0)
-
-  g0[4, 2] <- kit_drp <- gcombobox(
-    items = getKit(), selected = 1,
-    editable = FALSE, container = g0,
-    ellipsize = "none"
-  )
-
 
   # FRAME 1 ###################################################################
 
   f1 <- gframe(
     text = strFrmOptions,
     horizontal = FALSE,
-    spacing = 5,
+    spacing = 1,
     container = gv
   )
 
