@@ -1,5 +1,6 @@
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 05.09.2022: Compacted gui. Fixed narrow dropdowns. Removed destroy workaround.
 # 03.03.2020: Added language support.
 # 03.05.2019: Compacted gui and expand text field under tcltk.
 # 17.02.2019: Fixed Error in if (svalue(savegui_chk)) { : argument is of length zero (tcltk)
@@ -176,28 +177,13 @@ calculateMixture_gui <- function(env = parent.frame(), savegui = NULL,
       focus(parent)
     }
 
-    # Check which toolkit we are using.
-    if (gtoolkit() == "tcltk") {
-      if (as.numeric(gsub("[^0-9]", "", packageVersion("gWidgets2tcltk"))) <= 106) {
-        # Version <= 1.0.6 have the wrong implementation:
-        # See: https://stackoverflow.com/questions/54285836/how-to-retrieve-checkbox-state-in-gwidgets2tcltk-works-in-gwidgets2rgtk2
-        message("tcltk version <= 1.0.6, returned TRUE!")
-        return(TRUE) # Destroys window under tcltk, but not RGtk2.
-      } else {
-        # Version > 1.0.6 will be fixed:
-        # https://github.com/jverzani/gWidgets2tcltk/commit/9388900afc57454b6521b00a187ca4a16829df53
-        message("tcltk version >1.0.6, returned FALSE!")
-        return(FALSE) # Destroys window under tcltk, but not RGtk2.
-      }
-    } else {
-      message("RGtk2, returned FALSE!")
-      return(FALSE) # Destroys window under RGtk2, but not with tcltk.
-    }
+    # Destroy window.
+    return(FALSE)
   })
 
   gv <- ggroup(
     horizontal = FALSE,
-    spacing = 5,
+    spacing = 1,
     use.scrollwindow = FALSE,
     container = w,
     expand = TRUE
@@ -222,33 +208,38 @@ calculateMixture_gui <- function(env = parent.frame(), savegui = NULL,
 
   f0 <- gframe(
     text = strFrmDataset,
-    horizontal = TRUE,
-    spacing = 2,
-    container = gv
+    horizontal = FALSE,
+    spacing = 1,
+    container = gv,
+    expand = FALSE,
+    fill = "x"
   )
 
-  g0 <- glayout(container = f0, spacing = 1)
-
   # Dataset -------------------------------------------------------------------
 
-  g0[1, 1] <- glabel(text = strLblDataset, container = g0)
+  g0 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
 
-  dfs <- c(strDrpDefault, listObjects(env = env, obj.class = "data.frame"))
+  glabel(text = strLblDataset, container = g0)
 
-  g0[1, 2] <- g0_data_drp <- gcombobox(
-    items = dfs,
-    selected = 1,
-    editable = FALSE,
-    container = g0,
-    ellipsize = "none"
-  )
-  g0[1, 3] <- g0_data_samples_lbl <- glabel(
+  data_samples_lbl <- glabel(
     text = paste(" 0", strLblSamples),
     container = g0
   )
 
-  addHandlerChanged(g0_data_drp, handler = function(h, ...) {
-    val_obj <- svalue(g0_data_drp)
+  dfs <- c(strDrpDefault, listObjects(env = env, obj.class = "data.frame"))
+
+  data_drp <- gcombobox(
+    items = dfs,
+    selected = 1,
+    editable = FALSE,
+    container = g0,
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
+  )
+
+  addHandlerChanged(data_drp, handler = function(h, ...) {
+    val_obj <- svalue(data_drp)
 
     # Check if suitable.
     requiredCol <- c("Sample.Name", "Marker", "Allele")
@@ -264,7 +255,7 @@ calculateMixture_gui <- function(env = parent.frame(), savegui = NULL,
       # get dataset.
       .gData <<- get(val_obj, envir = env)
       .gNameData <<- val_obj
-      svalue(g0_data_samples_lbl) <- paste(
+      svalue(data_samples_lbl) <- paste(
         length(unique(.gData$Sample.Name)),
         strLblSamples
       )
@@ -274,32 +265,36 @@ calculateMixture_gui <- function(env = parent.frame(), savegui = NULL,
       # Reset components.
       .gData <<- NULL
       .gNameData <<- NULL
-      svalue(g0_data_drp, index = TRUE) <- 1
-      svalue(g0_data_samples_lbl) <- paste(" 0", strLblSamples)
+      svalue(data_drp, index = TRUE) <- 1
+      svalue(data_samples_lbl) <- paste(" 0", strLblSamples)
       svalue(save_edt) <- ""
     }
   })
 
   # Reference 1 ---------------------------------------------------------------
 
-  g0[2, 1] <- glabel(text = strLblRefMajor, container = g0)
+  g1 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
+
+  glabel(text = strLblRefMajor, container = g1)
+
+  ref1_samples_lbl <- glabel(
+    text = paste(" 0", strLblRef),
+    container = g1
+  )
 
   # NB! dfs defined in previous section.
-  g0[2, 2] <- g0_ref1_drp <- gcombobox(
+  ref1_drp <- gcombobox(
     items = dfs,
     selected = 1,
     editable = FALSE,
-    container = g0,
-    ellipsize = "none"
+    container = g1,
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
-  g0[2, 3] <- g0_ref1_samples_lbl <- glabel(
-    text = paste(" 0", strLblRef),
-    container = g0
-  )
-
-  addHandlerChanged(g0_ref1_drp, handler = function(h, ...) {
-    val_obj <- svalue(g0_ref1_drp)
+  addHandlerChanged(ref1_drp, handler = function(h, ...) {
+    val_obj <- svalue(ref1_drp)
 
     # Check if suitable.
     requiredCol <- c("Sample.Name", "Marker", "Allele")
@@ -314,7 +309,7 @@ calculateMixture_gui <- function(env = parent.frame(), savegui = NULL,
 
       .gRef1 <<- get(val_obj, envir = env)
       .gNameRef1 <<- val_obj
-      svalue(g0_ref1_samples_lbl) <- paste(
+      svalue(ref1_samples_lbl) <- paste(
         length(unique(.gRef1$Sample.Name)),
         strLblRef
       )
@@ -323,31 +318,35 @@ calculateMixture_gui <- function(env = parent.frame(), savegui = NULL,
       # Reset components.
       .gRef1 <<- NULL
       .gNameRef1 <<- NULL
-      svalue(g0_ref1_drp, index = TRUE) <- 1
-      svalue(g0_ref1_samples_lbl) <- paste(" 0", strLblRef)
+      svalue(ref1_drp, index = TRUE) <- 1
+      svalue(ref1_samples_lbl) <- paste(" 0", strLblRef)
     }
   })
 
   # Reference 2 ---------------------------------------------------------------
 
-  g0[3, 1] <- glabel(text = strLblRefMinor, container = g0)
+  g2 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
+
+  glabel(text = strLblRefMinor, container = g2)
+
+  ref2_samples_lbl <- glabel(
+    text = paste(" 0", strLblRef),
+    container = g2
+  )
 
   # NB! dfs defined in previous section.
-  g0[3, 2] <- g0_ref2_drp <- gcombobox(
+  ref2_drp <- gcombobox(
     items = dfs,
     selected = 1,
     editable = FALSE,
-    container = g0,
-    ellipsize = "none"
+    container = g2,
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
-  g0[3, 3] <- g0_ref2_samples_lbl <- glabel(
-    text = paste(" 0", strLblRef),
-    container = g0
-  )
-
-  addHandlerChanged(g0_ref2_drp, handler = function(h, ...) {
-    val_obj <- svalue(g0_ref2_drp)
+  addHandlerChanged(ref2_drp, handler = function(h, ...) {
+    val_obj <- svalue(ref2_drp)
 
     # Check if suitable.
     requiredCol <- c("Sample.Name", "Marker", "Allele")
@@ -362,7 +361,7 @@ calculateMixture_gui <- function(env = parent.frame(), savegui = NULL,
 
       .gRef2 <<- get(val_obj, envir = env)
       .gNameRef2 <<- val_obj
-      svalue(g0_ref2_samples_lbl) <- paste(
+      svalue(ref2_samples_lbl) <- paste(
         length(unique(.gRef2$Sample.Name)),
         strLblRef
       )
@@ -371,17 +370,16 @@ calculateMixture_gui <- function(env = parent.frame(), savegui = NULL,
       # Reset components.
       .gRef2 <<- NULL
       .gNameRef2 <<- NULL
-      svalue(g0_ref2_drp, index = TRUE) <- 1
-      svalue(g0_ref2_samples_lbl) <- paste(" 0", strLblRef)
+      svalue(ref2_drp, index = TRUE) <- 1
+      svalue(ref2_samples_lbl) <- paste(" 0", strLblRef)
     }
   })
 
+  # CHECK #####################################################################
 
-  # CHECK ---------------------------------------------------------------------
+  check_btn <- gbutton(text = strBtnCheck, container = gv)
 
-  g0[4, 2] <- g0_check_btn <- gbutton(text = strBtnCheck, container = g0)
-
-  addHandlerChanged(g0_check_btn, handler = function(h, ...) {
+  addHandlerChanged(check_btn, handler = function(h, ...) {
 
     # Get values.
     val_data <- .gData
@@ -436,12 +434,11 @@ calculateMixture_gui <- function(env = parent.frame(), savegui = NULL,
     }
   })
 
-
   # FRAME 1 ###################################################################
 
   f1 <- gframe(
     text = strFrmOptions, horizontal = FALSE,
-    spacing = 2, container = gv
+    spacing = 1, container = gv
   )
 
   f1_ol_chk <- gcheckbox(
