@@ -1,5 +1,6 @@
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 08.09.2022: Compacted gui. Fixed narrow dropdowns. Removed destroy workaround.
 # 07.03.2020: Added language support.
 # 17.02.2019: Fixed Error in if (svalue(savegui_chk)) { : argument is of length zero (tcltk)
 # 07.08.2017: Added audit trail.
@@ -190,28 +191,13 @@ calculateSlope_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
       focus(parent)
     }
 
-    # Check which toolkit we are using.
-    if (gtoolkit() == "tcltk") {
-      if (as.numeric(gsub("[^0-9]", "", packageVersion("gWidgets2tcltk"))) <= 106) {
-        # Version <= 1.0.6 have the wrong implementation:
-        # See: https://stackoverflow.com/questions/54285836/how-to-retrieve-checkbox-state-in-gwidgets2tcltk-works-in-gwidgets2rgtk2
-        message("tcltk version <= 1.0.6, returned TRUE!")
-        return(TRUE) # Destroys window under tcltk, but not RGtk2.
-      } else {
-        # Version > 1.0.6 will be fixed:
-        # https://github.com/jverzani/gWidgets2tcltk/commit/9388900afc57454b6521b00a187ca4a16829df53
-        message("tcltk version >1.0.6, returned FALSE!")
-        return(FALSE) # Destroys window under tcltk, but not RGtk2.
-      }
-    } else {
-      message("RGtk2, returned FALSE!")
-      return(FALSE) # Destroys window under RGtk2, but not with tcltk.
-    }
+    # Destroy window.
+    return(FALSE)
   })
 
   gv <- ggroup(
     horizontal = FALSE,
-    spacing = 8,
+    spacing = 1,
     use.scrollwindow = FALSE,
     container = w,
     expand = TRUE
@@ -237,17 +223,22 @@ calculateSlope_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
   f0 <- gframe(
     text = strFrmDataset,
     horizontal = FALSE,
-    spacing = 5,
+    spacing = 1,
     container = gv
   )
 
-  f0g0 <- glayout(container = f0, spacing = 1)
-
   # Datasets ------------------------------------------------------------------
 
-  f0g0[1, 1] <- glabel(text = strLblDataset, container = f0g0)
+  f0g0 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
 
-  f0g0[1, 2] <- f0_dataset_drp <- gcombobox(
+  glabel(text = strLblDataset, container = f0g0)
+
+  samples_lbl <- glabel(
+    text = paste(" 0", strLblSamples),
+    container = f0g0
+  )
+
+  dataset_drp <- gcombobox(
     items = c(
       strDrpDataset,
       listObjects(
@@ -258,16 +249,13 @@ calculateSlope_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
     selected = 1,
     editable = FALSE,
     container = f0g0,
-    ellipsize = "none"
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
-  f0g0[1, 3] <- f0_samples_lbl <- glabel(
-    text = paste(" 0", strLblSamples),
-    container = f0g0
-  )
-
-  addHandlerChanged(f0_dataset_drp, handler = function(h, ...) {
-    val_obj <- svalue(f0_dataset_drp)
+  addHandlerChanged(dataset_drp, handler = function(h, ...) {
+    val_obj <- svalue(dataset_drp)
 
     # Check if suitable.
     requiredCol <- c("Sample.Name", "Marker", "Allele", "Height")
@@ -283,7 +271,7 @@ calculateSlope_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
       .gData <<- get(val_obj, envir = env)
       .gDataName <<- val_obj
       samples <- length(unique(.gData$Sample.Name))
-      svalue(f0_samples_lbl) <- paste("", samples, strLblSamples)
+      svalue(samples_lbl) <- paste("", samples, strLblSamples)
       svalue(f2_save_edt) <- paste(.gDataName, "_slope", sep = "")
       svalue(f1_groups_lbl) <- paste(strLblGroups, unique(.gData$Group))
 
@@ -295,16 +283,25 @@ calculateSlope_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
 
       # Reset components.
       .gData <<- NULL
-      svalue(f0_dataset_drp, index = TRUE) <- 1
-      svalue(f0_samples_lbl) <- paste(" 0", strLblSamples)
+      svalue(dataset_drp, index = TRUE) <- 1
+      svalue(samples_lbl) <- paste(" 0", strLblSamples)
       svalue(f2_save_edt) <- ""
       svalue(f1_groups_lbl) <- paste(strLblGroups, "")
     }
   })
 
-  f0g0[2, 1] <- glabel(text = strLblRefDataset, container = f0g0)
+  # Reference -----------------------------------------------------------------
 
-  f0g0[2, 2] <- f0_refset_drp <- gcombobox(
+  f0g1 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
+
+  glabel(text = strLblRefDataset, container = f0g1)
+
+  ref_lbl <- glabel(
+    text = paste(" 0", strLblRef),
+    container = f0g1
+  )
+
+  refset_drp <- gcombobox(
     items = c(
       strDrpDataset,
       listObjects(
@@ -314,17 +311,14 @@ calculateSlope_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
     ),
     selected = 1,
     editable = FALSE,
-    container = f0g0,
-    ellipsize = "none"
+    container = f0g1,
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
-  f0g0[2, 3] <- f0_ref_lbl <- glabel(
-    text = paste(" 0", strLblRef),
-    container = f0g0
-  )
-
-  addHandlerChanged(f0_refset_drp, handler = function(h, ...) {
-    val_obj <- svalue(f0_refset_drp)
+  addHandlerChanged(refset_drp, handler = function(h, ...) {
+    val_obj <- svalue(refset_drp)
 
     # Check if suitable.
     requiredCol <- c("Sample.Name", "Marker", "Allele")
@@ -339,21 +333,21 @@ calculateSlope_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
       .gRef <<- get(val_obj, envir = env)
       .gRefName <<- val_obj
       refs <- length(unique(.gRef$Sample.Name))
-      svalue(f0_ref_lbl) <- paste("", refs, strLblRef)
+      svalue(ref_lbl) <- paste("", refs, strLblRef)
     } else {
 
       # Reset components.
       .gRef <<- NULL
-      svalue(f0_refset_drp, index = TRUE) <- 1
-      svalue(f0_ref_lbl) <- paste(" 0", strLblRef)
+      svalue(refset_drp, index = TRUE) <- 1
+      svalue(ref_lbl) <- paste(" 0", strLblRef)
     }
   })
 
-  # CHECK ---------------------------------------------------------------------
+  # CHECK #####################################################################
 
-  f0g0[3, 2] <- f0_check_btn <- gbutton(text = strBtnCheck, container = f0g0)
+  check_btn <- gbutton(text = strBtnCheck, container = gv)
 
-  addHandlerChanged(f0_check_btn, handler = function(h, ...) {
+  addHandlerChanged(check_btn, handler = function(h, ...) {
 
     # Get values.
     val_data <- .gData
@@ -399,7 +393,7 @@ calculateSlope_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
   f1 <- gframe(
     text = strFrmOptions,
     horizontal = FALSE,
-    spacing = 5,
+    spacing = 1,
     anchor = c(-1, 0),
     container = gv
   )
@@ -479,7 +473,7 @@ calculateSlope_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
 
   # FRAME 2 ###################################################################
 
-  f2 <- gframe(text = strFrmSave, horizontal = TRUE, spacing = 5, container = gv)
+  f2 <- gframe(text = strFrmSave, horizontal = TRUE, spacing = 1, container = gv)
 
   glabel(text = strLblSave, container = f2)
 
