@@ -1,5 +1,6 @@
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 09.09.2022: Compacted gui. Fixed narrow dropdowns. Removed destroy workaround.
 # 08.03.2020: Added language support.
 # 02.03.2019: Tweaked widgets under tcltk.
 # 17.02.2019: Fixed Error in if (svalue(savegui_chk)) { : argument is of length zero (tcltk)
@@ -278,29 +279,14 @@ cropData_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pa
       focus(parent)
     }
 
-    # Check which toolkit we are using.
-    if (gtoolkit() == "tcltk") {
-      if (as.numeric(gsub("[^0-9]", "", packageVersion("gWidgets2tcltk"))) <= 106) {
-        # Version <= 1.0.6 have the wrong implementation:
-        # See: https://stackoverflow.com/questions/54285836/how-to-retrieve-checkbox-state-in-gwidgets2tcltk-works-in-gwidgets2rgtk2
-        message("tcltk version <= 1.0.6, returned TRUE!")
-        return(TRUE) # Destroys window under tcltk, but not RGtk2.
-      } else {
-        # Version > 1.0.6 will be fixed:
-        # https://github.com/jverzani/gWidgets2tcltk/commit/9388900afc57454b6521b00a187ca4a16829df53
-        message("tcltk version >1.0.6, returned FALSE!")
-        return(FALSE) # Destroys window under tcltk, but not RGtk2.
-      }
-    } else {
-      message("RGtk2, returned FALSE!")
-      return(FALSE) # Destroys window under RGtk2, but not with tcltk.
-    }
+    # Destroy window.
+    return(FALSE)
   })
 
   # Vertical main group.
   gv <- ggroup(
     horizontal = FALSE,
-    spacing = 5,
+    spacing = 1,
     use.scrollwindow = FALSE,
     container = w,
     expand = TRUE
@@ -326,15 +312,17 @@ cropData_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pa
   f0 <- gframe(
     text = strFrmDataset,
     horizontal = FALSE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
-  g0 <- glayout(container = f0, spacing = 1)
+  # DATASET -------------------------------------------------------------------
 
-  g0[1, 1] <- glabel(text = strLblDataset, container = g0)
+  g0 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
 
-  g0[1, 2] <- dataset_drp <- gcombobox(
+  glabel(text = strLblDataset, container = g0)
+
+  dataset_drp <- gcombobox(
     items = c(
       strDrpDataset,
       listObjects(
@@ -345,16 +333,18 @@ cropData_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pa
     selected = 1,
     editable = FALSE,
     container = g0,
-    ellipsize = "none"
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
-  g0_samples_lbl <- glabel(text = paste(" <NA>", strLblSamples), container = g0)
-  g0_columns_lbl <- glabel(text = paste(" <NA>", strLblColumns), container = g0)
-  g0_rows_lbl <- glabel(text = paste(" <NA>", strLblRows), container = g0)
+  # SUMMARY -------------------------------------------------------------------
 
-  g0[1, 3] <- g0_samples_lbl
-  g0[1, 4] <- g0_columns_lbl
-  g0[1, 5] <- g0_rows_lbl
+  g1 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
+
+  samples_lbl <- glabel(text = paste(" <NA>", strLblSamples), container = g1)
+  columns_lbl <- glabel(text = paste(" <NA>", strLblColumns), container = g1)
+  rows_lbl <- glabel(text = paste(" <NA>", strLblRows), container = g1)
 
   addHandlerChanged(dataset_drp, handler = function(h, ...) {
     val_obj <- svalue(dataset_drp)
@@ -385,9 +375,9 @@ cropData_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pa
 
       # Update info prior to action.
       samples <- length(unique(.gData$Sample.Name))
-      svalue(g0_samples_lbl) <- paste(" ", samples, strLblSamples)
-      svalue(g0_columns_lbl) <- paste(" ", ncol(.gData), strLblColumns)
-      svalue(g0_rows_lbl) <- paste(" ", nrow(.gData), strLblRows)
+      svalue(samples_lbl) <- paste(" ", samples, strLblSamples)
+      svalue(columns_lbl) <- paste(" ", ncol(.gData), strLblColumns)
+      svalue(rows_lbl) <- paste(" ", nrow(.gData), strLblRows)
       .refresh_column_drp()
 
       # Update 'Save as'.
@@ -403,9 +393,9 @@ cropData_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pa
     } else {
       .gData <<- NULL
       .gDataName <<- NULL
-      svalue(g0_samples_lbl) <- paste(" <NA>", strLblSamples)
-      svalue(g0_columns_lbl) <- paste(" <NA>", strLblColumns)
-      svalue(g0_rows_lbl) <- paste(" <NA>", strLblRows)
+      svalue(samples_lbl) <- paste(" <NA>", strLblSamples)
+      svalue(columns_lbl) <- paste(" <NA>", strLblColumns)
+      svalue(rows_lbl) <- paste(" <NA>", strLblRows)
 
       # Update info:
       svalue(f1_min_lbl) <- " Min:"
@@ -424,7 +414,7 @@ cropData_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pa
   f1 <- gframe(
     text = strFrmColumn,
     horizontal = TRUE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
@@ -476,7 +466,7 @@ cropData_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pa
   f2 <- gframe(
     text = strFrmOptions,
     horizontal = FALSE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
@@ -484,7 +474,7 @@ cropData_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pa
 
   glabel(text = strLblAction, visible = FALSE, anchor = c(-1, -1), container = f2)
 
-  f2g1 <- glayout(container = f2, spacing = 2)
+  f2g1 <- glayout(container = f2, spacing = 1)
 
   f2g1[1, 1] <- f2g1_task_opt <- gradio(
     items = c(strRadDiscard, strRadReplace),
