@@ -1,5 +1,6 @@
 ################################################################################
 # CHANGE LOG
+# 10.09.2022: Compacted the gui. Fixed narrow dropdowns. Removed destroy workaround.
 # 16.03.2020: Added language support.
 # 03.03.2019: Compacted and tweaked widgets under tcltk.
 # 17.02.2019: Fixed Error in if (svalue(savegui_chk)) { : argument is of length zero (tcltk)
@@ -153,28 +154,13 @@ guessProfile_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE
       focus(parent)
     }
 
-    # Check which toolkit we are using.
-    if (gtoolkit() == "tcltk") {
-      if (as.numeric(gsub("[^0-9]", "", packageVersion("gWidgets2tcltk"))) <= 106) {
-        # Version <= 1.0.6 have the wrong implementation:
-        # See: https://stackoverflow.com/questions/54285836/how-to-retrieve-checkbox-state-in-gwidgets2tcltk-works-in-gwidgets2rgtk2
-        message("tcltk version <= 1.0.6, returned TRUE!")
-        return(TRUE) # Destroys window under tcltk, but not RGtk2.
-      } else {
-        # Version > 1.0.6 will be fixed:
-        # https://github.com/jverzani/gWidgets2tcltk/commit/9388900afc57454b6521b00a187ca4a16829df53
-        message("tcltk version >1.0.6, returned FALSE!")
-        return(FALSE) # Destroys window under tcltk, but not RGtk2.
-      }
-    } else {
-      message("RGtk2, returned FALSE!")
-      return(FALSE) # Destroys window under RGtk2, but not with tcltk.
-    }
+    # Destroy window.
+    return(FALSE)
   })
 
   gv <- ggroup(
     horizontal = FALSE,
-    spacing = 5,
+    spacing = 1,
     use.scrollwindow = FALSE,
     container = w,
     expand = TRUE
@@ -200,15 +186,22 @@ guessProfile_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE
   f0 <- gframe(
     text = strFrmDataset,
     horizontal = FALSE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
-  f0g0 <- glayout(container = f0, spacing = 1)
+  # Datasets ------------------------------------------------------------------
 
-  f0g0[1, 1] <- glabel(text = strLblDataset, container = f0g0)
+  f0g0 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
 
-  f0g0[1, 2] <- f0g0_dataset_drp <- gcombobox(
+  glabel(text = strLblDataset, container = f0g0)
+
+  samples_lbl <- glabel(
+    text = paste(" 0", strLblSamples),
+    container = f0g0
+  )
+
+  dataset_drp <- gcombobox(
     items = c(
       strDrpDataset,
       listObjects(
@@ -219,16 +212,13 @@ guessProfile_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE
     selected = 1,
     editable = FALSE,
     container = f0g0,
-    ellipsize = "none"
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
-  f0g0[1, 3] <- f0g0_samples_lbl <- glabel(
-    text = paste(" 0", strLblSamples),
-    container = f0g0
-  )
-
-  addHandlerChanged(f0g0_dataset_drp, handler = function(h, ...) {
-    val_obj <- svalue(f0g0_dataset_drp)
+  addHandlerChanged(dataset_drp, handler = function(h, ...) {
+    val_obj <- svalue(dataset_drp)
 
     # Check if suitable.
     requiredCol <- c("Sample.Name", "Marker", "Allele", "Height")
@@ -243,16 +233,16 @@ guessProfile_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE
       .gData <<- get(val_obj, envir = env)
       .gDataName <<- val_obj
       samples <- length(unique(.gData$Sample.Name))
-      svalue(f0g0_samples_lbl) <- paste(" ", samples, strLblSamples)
+      svalue(samples_lbl) <- paste(" ", samples, strLblSamples)
       svalue(save_edt) <- paste(val_obj, "_profile", sep = "")
     } else {
 
       # Reset components.
       .gData <<- data.frame(No.Data = NA)
       .gDataName <<- NULL
-      svalue(f0g0_samples_lbl) <- paste(" 0", strLblSamples)
+      svalue(samples_lbl) <- paste(" 0", strLblSamples)
       svalue(save_edt) <- ""
-      svalue(f0g0_dataset_drp, index = TRUE) <- 1
+      svalue(dataset_drp, index = TRUE) <- 1
     }
   })
 
@@ -261,11 +251,11 @@ guessProfile_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE
   f1 <- gframe(
     text = strFrmOptions,
     horizontal = FALSE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
-  f1g1 <- glayout(container = f1, spacing = 2)
+  f1g1 <- glayout(container = f1, spacing = 1)
 
   f1g1[1, 1] <- glabel(text = strLblRatio, container = f1g1)
 
