@@ -1,5 +1,7 @@
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 16.09.2022: Filename as suggested name for dataset for single file import.
+# 10.09.2022: Compacted the gui. Removed destroy workaround.
 # 16.03.2020: Added language support.
 # 17.03.2019: Fixed widgets not enabled.
 # 01.03.2019: Rearranged widgets and changed visibility for more intuitive options.
@@ -41,6 +43,7 @@
 #' @export
 #'
 #' @importFrom utils help
+#' @importFrom tools file_path_sans_ext
 #'
 #' @seealso \code{\link{import}}
 
@@ -242,29 +245,14 @@ import_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pare
       focus(parent)
     }
 
-    # Check which toolkit we are using.
-    if (gtoolkit() == "tcltk") {
-      if (as.numeric(gsub("[^0-9]", "", packageVersion("gWidgets2tcltk"))) <= 106) {
-        # Version <= 1.0.6 have the wrong implementation:
-        # See: https://stackoverflow.com/questions/54285836/how-to-retrieve-checkbox-state-in-gwidgets2tcltk-works-in-gwidgets2rgtk2
-        message("tcltk version <= 1.0.6, returned TRUE!")
-        return(TRUE) # Destroys window under tcltk, but not RGtk2.
-      } else {
-        # Version > 1.0.6 will be fixed:
-        # https://github.com/jverzani/gWidgets2tcltk/commit/9388900afc57454b6521b00a187ca4a16829df53
-        message("tcltk version >1.0.6, returned FALSE!")
-        return(FALSE) # Destroys window under tcltk, but not RGtk2.
-      }
-    } else {
-      message("RGtk2, returned FALSE!")
-      return(FALSE) # Destroys window under RGtk2, but not with tcltk.
-    }
+    # Destroy window.
+    return(FALSE)
   })
 
   # Vertical main group.
   gv <- ggroup(
     horizontal = FALSE,
-    spacing = 2,
+    spacing = 1,
     use.scrollwindow = FALSE,
     container = w,
     expand = TRUE
@@ -324,6 +312,8 @@ import_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pare
 
     # Update current selection.
     svalue(selected_lbl) <- paste0(c(strLblSelected, .selectedFile))
+    # Suggest filename as name for dataset.
+    svalue(import_edt) <- file_path_sans_ext(basename(.selectedFile))
   })
 
   # Button for multiple files import.
@@ -367,7 +357,7 @@ import_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pare
 
   opt_frm <- gframe(
     text = strFrmOptions, pos = 0, horizontal = FALSE,
-    spacing = 2, container = gv
+    spacing = 1, container = gv
   )
 
   # MULTIPLE FILES OPTIONS ----------------------------------------------------
