@@ -1,5 +1,6 @@
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 10.09.2022: Compacted the gui. Removed destroy workaround.
 # 04.07.2020: Fixed spelling error in variables.
 # 20.03.2020: Added language support.
 # 14.03.2019: Fixed R-Check note.
@@ -260,29 +261,14 @@ makeKit_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, par
       focus(parent)
     }
 
-    # Check which toolkit we are using.
-    if (gtoolkit() == "tcltk") {
-      if (as.numeric(gsub("[^0-9]", "", packageVersion("gWidgets2tcltk"))) <= 106) {
-        # Version <= 1.0.6 have the wrong implementation:
-        # See: https://stackoverflow.com/questions/54285836/how-to-retrieve-checkbox-state-in-gwidgets2tcltk-works-in-gwidgets2rgtk2
-        message("tcltk version <= 1.0.6, returned TRUE!")
-        return(TRUE) # Destroys window under tcltk, but not RGtk2.
-      } else {
-        # Version > 1.0.6 will be fixed:
-        # https://github.com/jverzani/gWidgets2tcltk/commit/9388900afc57454b6521b00a187ca4a16829df53
-        message("tcltk version >1.0.6, returned FALSE!")
-        return(FALSE) # Destroys window under tcltk, but not RGtk2.
-      }
-    } else {
-      message("RGtk2, returned FALSE!")
-      return(FALSE) # Destroys window under RGtk2, but not with tcltk.
-    }
+    # Destroy window.
+    return(FALSE)
   })
 
   # Vertical main group.
   gv <- ggroup(
     horizontal = FALSE,
-    spacing = 5,
+    spacing = 1,
     use.scrollwindow = FALSE,
     container = w,
     expand = TRUE
@@ -309,7 +295,7 @@ makeKit_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, par
   f0 <- gframe(
     text = strFrmAction,
     horizontal = FALSE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
@@ -327,7 +313,7 @@ makeKit_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, par
   f1 <- gframe(
     text = strFrmFile,
     horizontal = TRUE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
@@ -381,7 +367,7 @@ makeKit_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, par
   f2 <- gframe(
     text = strFrmNew,
     horizontal = FALSE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
@@ -487,10 +473,13 @@ makeKit_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, par
     use.scrollwindow = TRUE,
     expand = TRUE,
     fill = TRUE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
+  # Set initial minimal size.
+  size(f3) <- c(100, 150)
+
   # Function for updating GUI with kits.
   .update <- function(kitInfo, addKit) {
     # kitInfo - data.frame with kit information.
@@ -520,7 +509,7 @@ makeKit_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, par
     }
 
     # Add container.
-    .f3g1 <<- glayout(container = f3, spacing = 2, expand = TRUE, fill = "both")
+    .f3g1 <<- glayout(container = f3, spacing = 1, expand = TRUE, fill = "both")
 
     # Add titles.
     .f3g1[1, 1] <<- glabel(text = strLblRemove, container = .f3g1)
@@ -546,8 +535,8 @@ makeKit_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, par
         }
       } else {
         # Get current sex marker.
-        sexMarkers <- unique(kitInfo$Marker[kitInfo$Panel == panel[p]
-        & kitInfo$Sex.Marker])
+        sexMarkers <- unique(kitInfo$Marker[kitInfo$Panel == panel[p] &
+          kitInfo$Sex.Marker])
         if (length(sexMarkers) == 0) {
           # If no matching marker, set to no sex marker string.
           sexMarkers <- strLblNone
@@ -566,8 +555,8 @@ makeKit_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, par
         }
       } else {
         # Get current quality sensors.
-        qsMarkers <- unique(kitInfo$Marker[kitInfo$Panel == panel[p]
-        & kitInfo$Quality.Sensor])
+        qsMarkers <- unique(kitInfo$Marker[kitInfo$Panel == panel[p] &
+          kitInfo$Quality.Sensor])
         if (length(qsMarkers) == 0) {
           # If no matching marker, set to no qs marker string.
           qsMarkers <- strLblNone
@@ -603,7 +592,7 @@ makeKit_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, par
     text = strFrmSave,
     horizontal = FALSE,
     expand = FALSE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
