@@ -1,5 +1,6 @@
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 10.09.2022: Compacted the gui. Fixed narrow dropdowns. Removed destroy workaround.
 # 10.04.2020: Added language support.
 # 23.02.2019: Compacted and tweaked gui for tcltk.
 # 17.02.2019: Fixed Error in if (svalue(savegui_chk)) { : argument is of length zero (tcltk)
@@ -235,29 +236,14 @@ plotAT_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pare
       focus(parent)
     }
 
-    # Check which toolkit we are using.
-    if (gtoolkit() == "tcltk") {
-      if (as.numeric(gsub("[^0-9]", "", packageVersion("gWidgets2tcltk"))) <= 106) {
-        # Version <= 1.0.6 have the wrong implementation:
-        # See: https://stackoverflow.com/questions/54285836/how-to-retrieve-checkbox-state-in-gwidgets2tcltk-works-in-gwidgets2rgtk2
-        message("tcltk version <= 1.0.6, returned TRUE!")
-        return(TRUE) # Destroys window under tcltk, but not RGtk2.
-      } else {
-        # Version > 1.0.6 will be fixed:
-        # https://github.com/jverzani/gWidgets2tcltk/commit/9388900afc57454b6521b00a187ca4a16829df53
-        message("tcltk version >1.0.6, returned FALSE!")
-        return(FALSE) # Destroys window under tcltk, but not RGtk2.
-      }
-    } else {
-      message("RGtk2, returned FALSE!")
-      return(FALSE) # Destroys window under RGtk2, but not with tcltk.
-    }
+    # Destroy window.
+    return(FALSE)
   })
 
   # Vertical main group.
   gv <- ggroup(
     horizontal = FALSE,
-    spacing = 5,
+    spacing = 1,
     use.scrollwindow = FALSE,
     container = w,
     expand = TRUE
@@ -283,12 +269,17 @@ plotAT_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pare
   f0 <- gframe(
     text = strFrmDataset,
     horizontal = TRUE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
   glabel(text = strLblDataset, container = f0)
 
+  samples_lbl <- glabel(
+    text = paste("0", strLblSamples),
+    container = f0
+  )
+
   dataset_drp <- gcombobox(
     items = c(
       strDrpDataset,
@@ -300,12 +291,9 @@ plotAT_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pare
     selected = 1,
     editable = FALSE,
     container = f0,
-    ellipsize = "none"
-  )
-
-  f0_samples_lbl <- glabel(
-    text = paste("0", strLblSamples),
-    container = f0
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
   addHandlerChanged(dataset_drp, handler = function(h, ...) {
@@ -327,7 +315,7 @@ plotAT_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pare
       # Suggest name.
       svalue(f5_save_edt) <- paste(val_obj, "_ggplot", sep = "")
 
-      svalue(f0_samples_lbl) <- paste(
+      svalue(samples_lbl) <- paste(
         length(unique(.gData$Sample.Name)),
         strLblSamples
       )
@@ -340,7 +328,7 @@ plotAT_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pare
       .gData <<- NULL
       svalue(f5_save_edt) <- ""
       svalue(dataset_drp, index = TRUE) <- 1
-      svalue(f0_samples_lbl) <- paste("0", strLblSamples)
+      svalue(samples_lbl) <- paste("0", strLblSamples)
     }
   })
 
@@ -349,7 +337,7 @@ plotAT_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pare
   f1 <- gframe(
     text = strFrmOptions,
     horizontal = FALSE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
@@ -410,7 +398,7 @@ plotAT_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, pare
   f5 <- gframe(
     text = strFrmSave,
     horizontal = TRUE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
