@@ -1,5 +1,7 @@
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 10.09.2022: Compacted the gui. Fixed narrow dropdowns. Removed destroy workaround.
+# 09.07.2022: Fixed "...URLs which should use \doi (with the DOI name only)".
 # 18.04.2020: Added language support.
 # 23.02.2019: Compacted and tweaked gui for tcltk.
 # 17.02.2019: Fixed Error in if (svalue(savegui_chk)) { : argument is of length zero (tcltk)
@@ -41,7 +43,7 @@
 #'  Validating multiplexes for use in conjunction with modern interpretation strategies,
 #'  Forensic Science International: Genetics, Volume 20, January 2016,
 #'  Pages 6-19, ISSN 1872-4973, 10.1016/j.fsigen.2015.09.011.
-#' \url{http://www.sciencedirect.com/science/article/pii/S1872497315300739}
+#' \doi{10.1016/j.fsigen.2015.09.011}
 
 plotContamination_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE, parent = NULL) {
 
@@ -184,29 +186,14 @@ plotContamination_gui <- function(env = parent.frame(), savegui = NULL, debug =
       focus(parent)
     }
 
-    # Check which toolkit we are using.
-    if (gtoolkit() == "tcltk") {
-      if (as.numeric(gsub("[^0-9]", "", packageVersion("gWidgets2tcltk"))) <= 106) {
-        # Version <= 1.0.6 have the wrong implementation:
-        # See: https://stackoverflow.com/questions/54285836/how-to-retrieve-checkbox-state-in-gwidgets2tcltk-works-in-gwidgets2rgtk2
-        message("tcltk version <= 1.0.6, returned TRUE!")
-        return(TRUE) # Destroys window under tcltk, but not RGtk2.
-      } else {
-        # Version > 1.0.6 will be fixed:
-        # https://github.com/jverzani/gWidgets2tcltk/commit/9388900afc57454b6521b00a187ca4a16829df53
-        message("tcltk version >1.0.6, returned FALSE!")
-        return(FALSE) # Destroys window under tcltk, but not RGtk2.
-      }
-    } else {
-      message("RGtk2, returned FALSE!")
-      return(FALSE) # Destroys window under RGtk2, but not with tcltk.
-    }
+    # Destroy window.
+    return(FALSE)
   })
 
   # Vertical main group.
   gv <- ggroup(
     horizontal = FALSE,
-    spacing = 5,
+    spacing = 1,
     use.scrollwindow = FALSE,
     container = w,
     expand = TRUE
@@ -232,12 +219,17 @@ plotContamination_gui <- function(env = parent.frame(), savegui = NULL, debug =
   f0 <- gframe(
     text = strFrmDataset,
     horizontal = TRUE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
   glabel(text = strLblDataset, container = f0)
 
+  samples_lbl <- glabel(
+    text = paste(" 0 ", strLblSamples),
+    container = f0
+  )
+
   dataset_drp <- gcombobox(
     items = c(
       strDrpDataset,
@@ -249,12 +241,9 @@ plotContamination_gui <- function(env = parent.frame(), savegui = NULL, debug =
     selected = 1,
     editable = FALSE,
     container = f0,
-    ellipsize = "none"
-  )
-
-  f0_samples_lbl <- glabel(
-    text = paste(" (0 ", strLblSamples, ")"),
-    container = f0
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
   addHandlerChanged(dataset_drp, handler = function(h, ...) {
@@ -276,9 +265,9 @@ plotContamination_gui <- function(env = parent.frame(), savegui = NULL, debug =
       # Suggest name.
       svalue(f5_save_edt) <- paste(val_obj, "_ggplot", sep = "")
 
-      svalue(f0_samples_lbl) <- paste(" (",
+      svalue(samples_lbl) <- paste(" ",
         length(unique(.gData$Sample.Name)),
-        " ", strLblSamples, ")",
+        " ", strLblSamples,
         sep = ""
       )
 
@@ -290,7 +279,7 @@ plotContamination_gui <- function(env = parent.frame(), savegui = NULL, debug =
       .gData <<- NULL
       svalue(f5_save_edt) <- ""
       svalue(dataset_drp, index = TRUE) <- 1
-      svalue(f0_samples_lbl) <- paste(" (0 ", strLblSamples, ")")
+      svalue(samples_lbl) <- paste(" 0 ", strLblSamples)
     }
   })
 
@@ -299,7 +288,7 @@ plotContamination_gui <- function(env = parent.frame(), savegui = NULL, debug =
   f1 <- gframe(
     text = strFrmOptions,
     horizontal = FALSE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
@@ -361,7 +350,7 @@ plotContamination_gui <- function(env = parent.frame(), savegui = NULL, debug =
   f5 <- gframe(
     text = strFrmSave,
     horizontal = TRUE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
