@@ -1,5 +1,6 @@
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 10.09.2022: Compacted the gui. Removed destroy workaround.
 # 26.04.2020: Added language support.
 # 08.09.2019: Added option to override labels and titles.
 # 24.02.2019: Compacted and tweaked gui for tcltk.
@@ -85,7 +86,7 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
   strFrmDataset <- "Dataset and kit"
   strLblDataset <- "Precision dataset:"
   strDrpDataset <- "<Select dataset>"
-  strLblKit <- "and the kit used:"
+  strLblKit <- "Kit:"
   strFrmOptions <- "Options"
   strChkOverride <- "Override automatic titles"
   strExpTitles <- "Titles"
@@ -352,29 +353,14 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
       focus(parent)
     }
 
-    # Check which toolkit we are using.
-    if (gtoolkit() == "tcltk") {
-      if (as.numeric(gsub("[^0-9]", "", packageVersion("gWidgets2tcltk"))) <= 106) {
-        # Version <= 1.0.6 have the wrong implementation:
-        # See: https://stackoverflow.com/questions/54285836/how-to-retrieve-checkbox-state-in-gwidgets2tcltk-works-in-gwidgets2rgtk2
-        message("tcltk version <= 1.0.6, returned TRUE!")
-        return(TRUE) # Destroys window under tcltk, but not RGtk2.
-      } else {
-        # Version > 1.0.6 will be fixed:
-        # https://github.com/jverzani/gWidgets2tcltk/commit/9388900afc57454b6521b00a187ca4a16829df53
-        message("tcltk version >1.0.6, returned FALSE!")
-        return(FALSE) # Destroys window under tcltk, but not RGtk2.
-      }
-    } else {
-      message("RGtk2, returned FALSE!")
-      return(FALSE) # Destroys window under RGtk2, but not with tcltk.
-    }
+    # Destroy window.
+    return(FALSE)
   })
 
   # Vertical main group.
   gv <- ggroup(
     horizontal = FALSE,
-    spacing = 5,
+    spacing = 1,
     use.scrollwindow = FALSE,
     container = w,
     expand = TRUE
@@ -399,12 +385,16 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
 
   f0 <- gframe(
     text = strFrmDataset,
-    horizontal = TRUE,
-    spacing = 2,
+    horizontal = FALSE,
+    spacing = 1,
     container = gv
   )
 
-  glabel(text = strLblDataset, container = f0)
+  # Dataset -------------------------------------------------------------------
+
+  g0 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
+
+  glabel(text = strLblDataset, container = g0)
 
   dataset_drp <- gcombobox(
     items = c(
@@ -416,18 +406,26 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
     ),
     selected = 1,
     editable = FALSE,
-    container = f0,
-    ellipsize = "none"
+    container = g0,
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
-  glabel(text = strLblKit, container = f0)
+  # Kit -----------------------------------------------------------------------
+
+  g1 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
+
+  glabel(text = strLblKit, container = g1)
 
   kit_drp <- gcombobox(
     items = getKit(),
     selected = 1,
     editable = FALSE,
-    container = f0,
-    ellipsize = "none"
+    container = g1,
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
   addHandlerChanged(dataset_drp, handler = function(h, ...) {
@@ -475,7 +473,7 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
   f1 <- gframe(
     text = strFrmOptions,
     horizontal = FALSE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
@@ -793,7 +791,7 @@ plotPrecision_gui <- function(env = parent.frame(), savegui = NULL, debug = FALS
   f5 <- gframe(
     text = strFrmSave,
     horizontal = TRUE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
