@@ -1,5 +1,6 @@
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 10.09.2022: Compacted the gui. Fixed narrow dropdowns. Removed destroy workaround.
 # 04.07.2020: Fixed no visible binding for variables.
 # 02.05.2020: Added language support.
 # 24.02.2019: Compacted and tweaked gui for tcltk.
@@ -83,7 +84,7 @@ plotPullup_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE,
   strLblDataset <- "Pull-up dataset:"
   strDrpDataset <- "<Select dataset>"
   strLblSamples <- "samples"
-  strLblKit <- "and the kit used:"
+  strLblKit <- "Kit:"
   strFrmOptions <- "Options"
   strChkOverride <- "Override automatic titles"
   strLblTitlePlot <- "Plot title:"
@@ -269,29 +270,14 @@ plotPullup_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE,
       focus(parent)
     }
 
-    # Check which toolkit we are using.
-    if (gtoolkit() == "tcltk") {
-      if (as.numeric(gsub("[^0-9]", "", packageVersion("gWidgets2tcltk"))) <= 106) {
-        # Version <= 1.0.6 have the wrong implementation:
-        # See: https://stackoverflow.com/questions/54285836/how-to-retrieve-checkbox-state-in-gwidgets2tcltk-works-in-gwidgets2rgtk2
-        message("tcltk version <= 1.0.6, returned TRUE!")
-        return(TRUE) # Destroys window under tcltk, but not RGtk2.
-      } else {
-        # Version > 1.0.6 will be fixed:
-        # https://github.com/jverzani/gWidgets2tcltk/commit/9388900afc57454b6521b00a187ca4a16829df53
-        message("tcltk version >1.0.6, returned FALSE!")
-        return(FALSE) # Destroys window under tcltk, but not RGtk2.
-      }
-    } else {
-      message("RGtk2, returned FALSE!")
-      return(FALSE) # Destroys window under RGtk2, but not with tcltk.
-    }
+    # Destroy window.
+    return(FALSE)
   })
 
   # Vertical main group.
   gv <- ggroup(
     horizontal = FALSE,
-    spacing = 5,
+    spacing = 1,
     use.scrollwindow = FALSE,
     container = w,
     expand = TRUE
@@ -316,12 +302,21 @@ plotPullup_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE,
 
   f0 <- gframe(
     text = strFrmDataset,
-    horizontal = TRUE,
-    spacing = 2,
+    horizontal = FALSE,
+    spacing = 1,
     container = gv
   )
 
-  glabel(text = strLblDataset, container = f0)
+  # Dataset -------------------------------------------------------------------
+
+  g0 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
+
+  glabel(text = strLblDataset, container = g0)
+
+  samples_lbl <- glabel(
+    text = paste(" 0 ", strLblSamples, sep = ""),
+    container = g0
+  )
 
   dataset_drp <- gcombobox(
     items = c(
@@ -333,25 +328,30 @@ plotPullup_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE,
     ),
     selected = 1,
     editable = FALSE,
-    container = f0,
-    ellipsize = "none"
+    container = g0,
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
-  f0_samples_lbl <- glabel(
-    text = paste(" (0 ", strLblSamples, ") ", sep = ""),
-    container = f0
-  )
+  # Kit -----------------------------------------------------------------------
 
-  glabel(text = strLblKit, container = f0)
+  g1 <- ggroup(container = f0, spacing = 1, expand = TRUE, fill = "x")
+
+  glabel(text = strLblKit, container = g1)
 
   kit_drp <- gcombobox(
     items = getKit(),
     selected = 1,
     editable = FALSE,
-    container = f0,
-    ellipsize = "none"
+    container = g1,
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
+  # Handlers ------------------------------------------------------------------
+
   addHandlerChanged(dataset_drp, handler = function(h, ...) {
     val_obj <- svalue(dataset_drp)
 
@@ -376,9 +376,9 @@ plotPullup_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE,
       # Suggest name.
       svalue(f5_save_edt) <- paste(val_obj, "_ggplot", sep = "")
 
-      svalue(f0_samples_lbl) <- paste(" (",
+      svalue(samples_lbl) <- paste(" ",
         length(unique(.gData$Sample.Name)),
-        " ", strLblSamples, ")",
+        " ", strLblSamples,
         sep = ""
       )
 
@@ -395,7 +395,7 @@ plotPullup_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE,
       .gData <<- NULL
       svalue(f5_save_edt) <- ""
       svalue(dataset_drp, index = TRUE) <- 1
-      svalue(f0_samples_lbl) <- paste(" (0 ", strLblSamples, ") ", sep = "")
+      svalue(samples_lbl) <- paste(" 0 ", strLblSamples, sep = "")
     }
   })
 
@@ -404,7 +404,7 @@ plotPullup_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE,
   f1 <- gframe(
     text = strFrmOptions,
     horizontal = FALSE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
@@ -514,7 +514,7 @@ plotPullup_gui <- function(env = parent.frame(), savegui = NULL, debug = FALSE,
   f5 <- gframe(
     text = strFrmSave,
     horizontal = TRUE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
