@@ -1,5 +1,6 @@
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 10.09.2022: Compacted the gui. Fixed narrow dropdowns. Removed destroy workaround.
 # 02.05.2020: Added language support.
 # 24.02.2019: Compacted and tweaked gui for tcltk.
 # 17.02.2019: Fixed Error in if (svalue(savegui_chk)) { : argument is of length zero (tcltk)
@@ -224,28 +225,13 @@ plotResultType_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
       focus(parent)
     }
 
-    # Check which toolkit we are using.
-    if (gtoolkit() == "tcltk") {
-      if (as.numeric(gsub("[^0-9]", "", packageVersion("gWidgets2tcltk"))) <= 106) {
-        # Version <= 1.0.6 have the wrong implementation:
-        # See: https://stackoverflow.com/questions/54285836/how-to-retrieve-checkbox-state-in-gwidgets2tcltk-works-in-gwidgets2rgtk2
-        message("tcltk version <= 1.0.6, returned TRUE!")
-        return(TRUE) # Destroys window under tcltk, but not RGtk2.
-      } else {
-        # Version > 1.0.6 will be fixed:
-        # https://github.com/jverzani/gWidgets2tcltk/commit/9388900afc57454b6521b00a187ca4a16829df53
-        message("tcltk version >1.0.6, returned FALSE!")
-        return(FALSE) # Destroys window under tcltk, but not RGtk2.
-      }
-    } else {
-      message("RGtk2, returned FALSE!")
-      return(FALSE) # Destroys window under RGtk2, but not with tcltk.
-    }
+    # Destroy window.
+    return(FALSE)
   })
 
   gv <- ggroup(
     horizontal = FALSE,
-    spacing = 5,
+    spacing = 1,
     use.scrollwindow = FALSE,
     container = w,
     expand = TRUE
@@ -271,12 +257,17 @@ plotResultType_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
   f0 <- gframe(
     text = strFrmDataset,
     horizontal = TRUE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
   glabel(text = strLblDataset, container = f0)
 
+  samples_lbl <- glabel(
+    text = paste(" 0 ", strLblSamples, sep = ""),
+    container = f0
+  )
+
   dataset_drp <- gcombobox(
     items = c(
       strDrpDataset,
@@ -288,12 +279,9 @@ plotResultType_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
     selected = 1,
     editable = FALSE,
     container = f0,
-    ellipsize = "none"
-  )
-
-  f0_samples_lbl <- glabel(
-    text = paste(" (0 ", strLblSamples, ")", sep = ""),
-    container = f0
+    ellipsize = "none",
+    expand = TRUE,
+    fill = "x"
   )
 
   addHandlerChanged(dataset_drp, handler = function(h, ...) {
@@ -315,9 +303,9 @@ plotResultType_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
       # Suggest name.
       svalue(f5_save_edt) <- paste(val_obj, "_ggplot", sep = "")
 
-      svalue(f0_samples_lbl) <- paste(" (",
+      svalue(samples_lbl) <- paste(" ",
         nrow(.gData),
-        " ", strLblSamples, ")",
+        " ", strLblSamples,
         sep = ""
       )
 
@@ -329,7 +317,7 @@ plotResultType_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
       .gData <<- NULL
       svalue(f5_save_edt) <- ""
       svalue(dataset_drp, index = TRUE) <- 1
-      svalue(f0_samples_lbl) <- paste(" (0 ", strLblSamples, ")", sep = "")
+      svalue(samples_lbl) <- paste(" 0 ", strLblSamples, sep = "")
     }
   })
 
@@ -338,7 +326,7 @@ plotResultType_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
   f1 <- gframe(
     text = strFrmOptions,
     horizontal = FALSE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
@@ -415,7 +403,7 @@ plotResultType_gui <- function(env = parent.frame(), savegui = NULL, debug = FAL
   f5 <- gframe(
     text = strFrmSave,
     horizontal = TRUE,
-    spacing = 2,
+    spacing = 1,
     container = gv
   )
 
